@@ -63,7 +63,9 @@ sub run {
 
 sub repository_base {
     my $self = shift;
-    Path::Tiny->new($ENV{PERL_CARMEL_REPO} || "$ENV{HOME}/.carmel/" . $self->perl_arch);
+
+    my $home = $ENV{HOME} || $ENV{HOMEPATH};
+    Path::Tiny->new($ENV{PERL_CARMEL_REPO} || "$home/.carmel/" . $self->perl_arch);
 }
 
 sub repo {
@@ -98,7 +100,7 @@ sub cmd_install {
     die "Usage: carmel install\n" if @args;
 
     $self->install_from_cpanfile;
-    $self->dump_bootstrap;
+    $self->post_install;
 }
 
 sub install_from_cpanfile {
@@ -155,7 +157,11 @@ sub install_with_cpanfile {
 sub install {
     my($self, @args) = @_;
 
-    my $dir = Path::Tiny->tempdir;
+    my %file_temp = ();
+    $file_temp{CLEANUP} = $ENV{PERL_FILE_TEMP_CLEANUP}
+      if exists $ENV{PERL_FILE_TEMP_CLEANUP};
+
+    my $dir = Path::Tiny->tempdir(%file_temp);
     local $ENV{PERL_CPANM_HOME} = $dir;
     local $ENV{PERL_CPANM_OPT};
 
@@ -204,23 +210,53 @@ sub transform {
     }
 }
 
-sub dump_bootstrap {
-    my($self) = @_;
+sub post_install {
+    my $self = shift;
 
     my @artifacts;
     $self->resolve(sub { push @artifacts, $_[0] });
 
-    my @inc  = map $_->nonempty_libs, @artifacts;
-    my @path = map $_->nonempty_paths, @artifacts;
+    $self->dump_bootstrap(\@artifacts);
+    $self->save_snapshot(\@artifacts);
+}
+
+sub save_snapshot {
+    my($self, $artifacts) = @_;
+
+    require Carton::Dist;
+    require Carton::Snapshot;
+
+    my $cpanfile = $self->try_cpanfile;
+    my $snapshot = Carton::Snapshot->new(path => $cpanfile . ".snapshot");
+
+    for my $artifact (@$artifacts) {
+        my $dist = Carton::Dist->new(
+            name => $artifact->distname,
+            pathname => $artifact->install->{pathname},
+            provides => $artifact->provides,
+            version => $artifact->version,
+            requirements => $artifact->requirements,
+        );
+        $snapshot->add_distribution($dist);
+    }
+
+    $snapshot->save;
+}
+
+sub dump_bootstrap {
+    my($self, $artifacts) = @_;
+
+    my @inc  = map $_->nonempty_libs, @$artifacts;
+    my @path = map $_->nonempty_paths, @$artifacts;
 
     my(%execs);
-    for my $artifact (@artifacts) {
+    for my $artifact (@$artifacts) {
         my %bins = $artifact->executables;
         $execs{$artifact->package} = \%bins if %bins;
     }
 
     my %modules;
-    for my $artifact (@artifacts) {
+    for my $artifact (@$artifacts) {
         %modules = (%modules, $artifact->module_files);
     }
 
